Class: Google::Apis::MetastoreV1alpha::AuxiliaryVersionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Configuration information for the auxiliary service versions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuxiliaryVersionConfig

Returns a new instance of AuxiliaryVersionConfig.



232
233
234
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_overridesHash<String,String>

Optional. A mapping of Hive metastore configuration key-value pairs to apply to the auxiliary Hive metastore (configured in hive-site.xml) in addition to the primary version's overrides. If keys are present in both the auxiliary version's overrides and the primary version's overrides, the value from the auxiliary version's overrides takes precedence. Corresponds to the JSON property configOverrides

Returns:

  • (Hash<String,String>)


219
220
221
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 219

def config_overrides
  @config_overrides
end

#network_configGoogle::Apis::MetastoreV1alpha::NetworkConfig

Network configuration for the Dataproc Metastore service. Corresponds to the JSON property networkConfig



224
225
226
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 224

def network_config
  @network_config
end

#versionString

Optional. The Hive metastore version of the auxiliary service. It must be less than the primary Hive metastore service's version. Corresponds to the JSON property version

Returns:

  • (String)


230
231
232
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 230

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



237
238
239
240
241
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 237

def update!(**args)
  @config_overrides = args[:config_overrides] if args.key?(:config_overrides)
  @network_config = args[:network_config] if args.key?(:network_config)
  @version = args[:version] if args.key?(:version)
end