Class: Google::Apis::MetastoreV1alpha::CatalogReport
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::CatalogReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Aggregated report at the catalog level.
Instance Attribute Summary collapse
-
#catalog ⇒ String
The name of the catalog (format: projects//catalogs/).
-
#catalog_type ⇒ String
The type of catalog.
-
#database_reports ⇒ Hash<String,Google::Apis::MetastoreV1alpha::DatabaseReport>
A map of database names to their respective reports.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CatalogReport
constructor
A new instance of CatalogReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CatalogReport
Returns a new instance of CatalogReport.
589 590 591 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 589 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog ⇒ String
The name of the catalog (format: projects//catalogs/).
Corresponds to the JSON property catalog
577 578 579 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 577 def catalog @catalog end |
#catalog_type ⇒ String
The type of catalog.
Corresponds to the JSON property catalogType
582 583 584 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 582 def catalog_type @catalog_type end |
#database_reports ⇒ Hash<String,Google::Apis::MetastoreV1alpha::DatabaseReport>
A map of database names to their respective reports.
Corresponds to the JSON property databaseReports
587 588 589 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 587 def database_reports @database_reports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
594 595 596 597 598 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 594 def update!(**args) @catalog = args[:catalog] if args.key?(:catalog) @catalog_type = args[:catalog_type] if args.key?(:catalog_type) @database_reports = args[:database_reports] if args.key?(:database_reports) end |