Class: Google::Apis::MetastoreV1alpha::CloudSqlConnectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Configuration information to establish customer database connection before the cutover phase of migration

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudSqlConnectionConfig

Returns a new instance of CloudSqlConnectionConfig.



760
761
762
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hive_database_nameString

Required. The hive database name. Corresponds to the JSON property hiveDatabaseName

Returns:

  • (String)


711
712
713
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 711

def hive_database_name
  @hive_database_name
end

#instance_connection_nameString

Required. Cloud SQL database connection name (project_id:region:instance_name) Corresponds to the JSON property instanceConnectionName

Returns:

  • (String)


716
717
718
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 716

def instance_connection_name
  @instance_connection_name
end

#ip_addressString

Required. The private IP address of the Cloud SQL instance. Corresponds to the JSON property ipAddress

Returns:

  • (String)


721
722
723
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 721

def ip_address
  @ip_address
end

#nat_subnetString

Required. The relative resource name of the subnetwork to be used for Private Service Connect. Note that this cannot be a regular subnet and is used only for NAT. (https://cloud.google.com/vpc/docs/about-vpc-hosted-services#psc- subnets) This subnet is used to publish the SOCKS5 proxy service. The subnet size must be at least /29 and it should reside in a network through which the Cloud SQL instance is accessible. The resource name should be in the format, projects/project_id/regions/region_id/subnetworks/subnetwork_id Corresponds to the JSON property natSubnet

Returns:

  • (String)


732
733
734
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 732

def nat_subnet
  @nat_subnet
end

#passwordString

Required. Input only. The password for the user that Dataproc Metastore service will be using to connect to the database. This field is not returned on request. Corresponds to the JSON property password

Returns:

  • (String)


739
740
741
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 739

def password
  @password
end

#portFixnum

Required. The network port of the database. Corresponds to the JSON property port

Returns:

  • (Fixnum)


744
745
746
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 744

def port
  @port
end

#proxy_subnetString

Required. The relative resource name of the subnetwork to deploy the SOCKS5 proxy service in. The subnetwork should reside in a network through which the Cloud SQL instance is accessible. The resource name should be in the format, projects/project_id/regions/region_id/subnetworks/subnetwork_id Corresponds to the JSON property proxySubnet

Returns:

  • (String)


752
753
754
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 752

def proxy_subnet
  @proxy_subnet
end

#usernameString

Required. The username that Dataproc Metastore service will use to connect to the database. Corresponds to the JSON property username

Returns:

  • (String)


758
759
760
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 758

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



765
766
767
768
769
770
771
772
773
774
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 765

def update!(**args)
  @hive_database_name = args[:hive_database_name] if args.key?(:hive_database_name)
  @instance_connection_name = args[:instance_connection_name] if args.key?(:instance_connection_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @nat_subnet = args[:nat_subnet] if args.key?(:nat_subnet)
  @password = args[:password] if args.key?(:password)
  @port = args[:port] if args.key?(:port)
  @proxy_subnet = args[:proxy_subnet] if args.key?(:proxy_subnet)
  @username = args[:username] if args.key?(:username)
end