Class: Google::Apis::MetastoreV1alpha::CloudSqlMigrationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Deprecated: Migrations to Dataproc Metastore are no longer supported. Use BigLake Metastore migration instead. Configuration information for migrating from self-managed hive metastore on Google Cloud using Cloud SQL as the backend database to Dataproc Metastore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudSqlMigrationConfig

Returns a new instance of CloudSqlMigrationConfig.



796
797
798
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cdc_configGoogle::Apis::MetastoreV1alpha::CdcConfig

Configuration information to start the Change Data Capture (CDC) streams from customer database to backend database of Dataproc Metastore. Corresponds to the JSON property cdcConfig



788
789
790
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 788

def cdc_config
  @cdc_config
end

#cloud_sql_connection_configGoogle::Apis::MetastoreV1alpha::CloudSqlConnectionConfig

Configuration information to establish customer database connection before the cutover phase of migration Corresponds to the JSON property cloudSqlConnectionConfig



794
795
796
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 794

def cloud_sql_connection_config
  @cloud_sql_connection_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



801
802
803
804
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 801

def update!(**args)
  @cdc_config = args[:cdc_config] if args.key?(:cdc_config)
  @cloud_sql_connection_config = args[:cloud_sql_connection_config] if args.key?(:cloud_sql_connection_config)
end