Class: Google::Apis::MetastoreV1alpha::Consumer
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::Consumer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Contains information of the customer's network configurations.
Instance Attribute Summary collapse
-
#endpoint_location ⇒ String
Output only.
-
#endpoint_uri ⇒ String
Output only.
-
#subnetwork ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Consumer
constructor
A new instance of Consumer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Consumer
Returns a new instance of Consumer.
866 867 868 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint_location ⇒ String
Output only. The location of the endpoint URI. Format: projects/project/
locations/location.
Corresponds to the JSON property endpointLocation
849 850 851 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 849 def endpoint_location @endpoint_location end |
#endpoint_uri ⇒ String
Output only. The URI of the endpoint used to access the metastore service.
Corresponds to the JSON property endpointUri
854 855 856 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 854 def endpoint_uri @endpoint_uri end |
#subnetwork ⇒ String
Immutable. The subnetwork of the customer project from which an IP address is
reserved and used as the Dataproc Metastore service's endpoint. It is
accessible to hosts in the subnet and to all hosts in a subnet in the same
region and same network. There must be at least one IP address available in
the subnet's primary range. The subnet is specified in the following form:
projects/project_number/regions/region_id/subnetworks/subnetwork_id
Corresponds to the JSON property subnetwork
864 865 866 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 864 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
871 872 873 874 875 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 871 def update!(**args) @endpoint_location = args[:endpoint_location] if args.key?(:endpoint_location) @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |