Class: Google::Apis::MetastoreV1alpha::DataCatalogConfig
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::DataCatalogConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Specifies how metastore metadata should be integrated with the Data Catalog service.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataCatalogConfig
constructor
A new instance of DataCatalogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataCatalogConfig
Returns a new instance of DataCatalogConfig.
953 954 955 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 953 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Optional. Defines whether the metastore metadata should be synced to Data
Catalog. The default value is to disable syncing metastore metadata to Data
Catalog.
Corresponds to the JSON property enabled
950 951 952 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 950 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
958 959 960 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 958 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |