Class: Google::Apis::MetastoreV1alpha::DatabaseReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Aggregated report at the database level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseReport

Returns a new instance of DatabaseReport.



1027
1028
1029
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#databaseString

The name of the database. Corresponds to the JSON property database

Returns:

  • (String)


1009
1010
1011
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1009

def database
  @database
end

#execution_planGoogle::Apis::MetastoreV1alpha::ExecutionPlan

Represents the migration plan for a specific resource (e.g. Database, Table). Corresponds to the JSON property executionPlan



1014
1015
1016
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1014

def execution_plan
  @execution_plan
end

#execution_resultGoogle::Apis::MetastoreV1alpha::ExecutionResult

Represents the actual migration result for a specific resource (e.g. Database, Table). Corresponds to the JSON property executionResult



1020
1021
1022
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1020

def execution_result
  @execution_result
end

#table_reportsHash<String,Google::Apis::MetastoreV1alpha::TableReport>

A map of table names to their respective reports. Corresponds to the JSON property tableReports



1025
1026
1027
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1025

def table_reports
  @table_reports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1032
1033
1034
1035
1036
1037
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1032

def update!(**args)
  @database = args[:database] if args.key?(:database)
  @execution_plan = args[:execution_plan] if args.key?(:execution_plan)
  @execution_result = args[:execution_result] if args.key?(:execution_result)
  @table_reports = args[:table_reports] if args.key?(:table_reports)
end