Class: Google::Apis::MetastoreV1alpha::DatabaseSummary
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::DatabaseSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Summary of results for a specific database in a catalog.
Instance Attribute Summary collapse
-
#database ⇒ String
Output only.
-
#plan_action ⇒ String
Output only.
-
#result_status ⇒ String
Output only.
-
#table_summary ⇒ Google::Apis::MetastoreV1alpha::TableSummary
Aggregated summary of results for all tables in a database.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseSummary
constructor
A new instance of DatabaseSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseSummary
Returns a new instance of DatabaseSummary.
1065 1066 1067 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database ⇒ String
Output only. The name of the database.
Corresponds to the JSON property database
1047 1048 1049 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1047 def database @database end |
#plan_action ⇒ String
Output only. The migration plan action for the database.
Corresponds to the JSON property planAction
1052 1053 1054 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1052 def plan_action @plan_action end |
#result_status ⇒ String
Output only. The migration result status for the database. This is only set if
the migration is not a dry run.
Corresponds to the JSON property resultStatus
1058 1059 1060 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1058 def result_status @result_status end |
#table_summary ⇒ Google::Apis::MetastoreV1alpha::TableSummary
Aggregated summary of results for all tables in a database.
Corresponds to the JSON property tableSummary
1063 1064 1065 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1063 def table_summary @table_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1070 1071 1072 1073 1074 1075 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1070 def update!(**args) @database = args[:database] if args.key?(:database) @plan_action = args[:plan_action] if args.key?(:plan_action) @result_status = args[:result_status] if args.key?(:result_status) @table_summary = args[:table_summary] if args.key?(:table_summary) end |