Class: Google::Apis::MetastoreV1alpha::ExecutionPlan

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Represents the migration plan for a specific resource (e.g. Database, Table).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecutionPlan

Returns a new instance of ExecutionPlan.



1185
1186
1187
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

The action that will be taken for a resource during migration. Corresponds to the JSON property action

Returns:

  • (String)


1173
1174
1175
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1173

def action
  @action
end

#diffsHash<String,Google::Apis::MetastoreV1alpha::ValueDiff>

A map of field names to their respective value diff. Corresponds to the JSON property diffs



1178
1179
1180
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1178

def diffs
  @diffs
end

#reasonString

A human-readable string explaining why the action was chosen. Corresponds to the JSON property reason

Returns:

  • (String)


1183
1184
1185
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1183

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1190
1191
1192
1193
1194
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1190

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @diffs = args[:diffs] if args.key?(:diffs)
  @reason = args[:reason] if args.key?(:reason)
end