Class: Google::Apis::MetastoreV1alpha::ExecutionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Represents the actual migration result for a specific resource (e.g. Database, Table).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecutionResult

Returns a new instance of ExecutionResult.



1217
1218
1219
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1217

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_messageString

Description of the error if the state is FAILED. Corresponds to the JSON property errorMessage

Returns:

  • (String)


1205
1206
1207
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1205

def error_message
  @error_message
end

#remediationString

Remediation steps for the error if the state is FAILED. Corresponds to the JSON property remediation

Returns:

  • (String)


1210
1211
1212
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1210

def remediation
  @remediation
end

#stateString

Output only. The state of the migration for a resource. Corresponds to the JSON property state

Returns:

  • (String)


1215
1216
1217
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1215

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1222
1223
1224
1225
1226
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1222

def update!(**args)
  @error_message = args[:error_message] if args.key?(:error_message)
  @remediation = args[:remediation] if args.key?(:remediation)
  @state = args[:state] if args.key?(:state)
end