Class: Google::Apis::MetastoreV1alpha::Federation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Represents a federation of multiple backend metastores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Federation

Returns a new instance of Federation.



1392
1393
1394
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1392

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_metastoresHash<String,Google::Apis::MetastoreV1alpha::BackendMetastore>

A map from BackendMetastore rank to BackendMetastores from which the federation service serves metadata at query time. The map key represents the order in which BackendMetastores should be evaluated to resolve database names at query time and should be greater than or equal to zero. A BackendMetastore with a lower number will be evaluated before a BackendMetastore with a higher number. Corresponds to the JSON property backendMetastores



1334
1335
1336
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1334

def backend_metastores
  @backend_metastores
end

#create_timeString

Output only. The time when the metastore federation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1339
1340
1341
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1339

def create_time
  @create_time
end

#endpoint_uriString

Output only. The federation endpoint. Corresponds to the JSON property endpointUri

Returns:

  • (String)


1344
1345
1346
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1344

def endpoint_uri
  @endpoint_uri
end

#labelsHash<String,String>

User-defined labels for the metastore federation. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1349
1350
1351
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1349

def labels
  @labels
end

#nameString

Immutable. The relative resource name of the federation, of the form: projects/ project_number/locations/location_id/federations/federation_id. Corresponds to the JSON propertyname`

Returns:

  • (String)


1355
1356
1357
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1355

def name
  @name
end

#stateString

Output only. The current state of the federation. Corresponds to the JSON property state

Returns:

  • (String)


1360
1361
1362
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1360

def state
  @state
end

#state_messageString

Output only. Additional information about the current state of the metastore federation, if available. Corresponds to the JSON property stateMessage

Returns:

  • (String)


1366
1367
1368
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1366

def state_message
  @state_message
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": " marketing" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


1373
1374
1375
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1373

def tags
  @tags
end

#uidString

Output only. The globally unique resource identifier of the metastore federation. Corresponds to the JSON property uid

Returns:

  • (String)


1379
1380
1381
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1379

def uid
  @uid
end

#update_timeString

Output only. The time when the metastore federation was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1384
1385
1386
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1384

def update_time
  @update_time
end

#versionString

Immutable. The Apache Hive metastore version of the federation. All backend metastore versions must be compatible with the federation version. Corresponds to the JSON property version

Returns:

  • (String)


1390
1391
1392
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1390

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1397

def update!(**args)
  @backend_metastores = args[:backend_metastores] if args.key?(:backend_metastores)
  @create_time = args[:create_time] if args.key?(:create_time)
  @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @tags = args[:tags] if args.key?(:tags)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end