Class: Google::Apis::MetastoreV1alpha::HiveMetastoreConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Specifies configuration information specific to running Hive metastore software as the metastore service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HiveMetastoreConfig

Returns a new instance of HiveMetastoreConfig.



1482
1483
1484
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auxiliary_versionsHash<String,Google::Apis::MetastoreV1alpha::AuxiliaryVersionConfig>

Optional. A mapping of Hive metastore version to the auxiliary version configuration. When specified, a secondary Hive metastore service is created along with the primary service. All auxiliary versions must be less than the service's primary version. The key is the auxiliary service name and it must match the regular expression a-z?. This means that the first character must be a lowercase letter, and all the following characters must be hyphens, lowercase letters, or digits, except the last character, which cannot be a hyphen. Corresponds to the JSON property auxiliaryVersions



1455
1456
1457
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1455

def auxiliary_versions
  @auxiliary_versions
end

#config_overridesHash<String,String>

Optional. A mapping of Hive metastore configuration key-value pairs to apply to the Hive metastore (configured in hive-site.xml). The mappings override system defaults (some keys cannot be overridden). These overrides are also applied to auxiliary versions and can be further customized in the auxiliary version's AuxiliaryVersionConfig. Corresponds to the JSON property configOverrides

Returns:

  • (Hash<String,String>)


1464
1465
1466
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1464

def config_overrides
  @config_overrides
end

#endpoint_protocolString

Optional. The protocol to use for the metastore service endpoint. If unspecified, defaults to THRIFT. Corresponds to the JSON property endpointProtocol

Returns:

  • (String)


1470
1471
1472
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1470

def endpoint_protocol
  @endpoint_protocol
end

#kerberos_configGoogle::Apis::MetastoreV1alpha::KerberosConfig

Configuration information for a Kerberos principal. Corresponds to the JSON property kerberosConfig



1475
1476
1477
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1475

def kerberos_config
  @kerberos_config
end

#versionString

Immutable. The Hive metastore schema version. Corresponds to the JSON property version

Returns:

  • (String)


1480
1481
1482
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1480

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1487
1488
1489
1490
1491
1492
1493
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1487

def update!(**args)
  @auxiliary_versions = args[:auxiliary_versions] if args.key?(:auxiliary_versions)
  @config_overrides = args[:config_overrides] if args.key?(:config_overrides)
  @endpoint_protocol = args[:endpoint_protocol] if args.key?(:endpoint_protocol)
  @kerberos_config = args[:kerberos_config] if args.key?(:kerberos_config)
  @version = args[:version] if args.key?(:version)
end