Class: Google::Apis::MetastoreV1alpha::KerberosConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Configuration information for a Kerberos principal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KerberosConfig

Returns a new instance of KerberosConfig.



1574
1575
1576
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keytabGoogle::Apis::MetastoreV1alpha::Secret

A securely stored value. Corresponds to the JSON property keytab



1558
1559
1560
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1558

def keytab
  @keytab
end

#krb5_config_gcs_uriString

Optional. A Cloud Storage URI that specifies the path to a krb5.conf file. It is of the form gs://bucket_name/path/to/krb5.conf, although the file does not need to be named krb5.conf explicitly. Corresponds to the JSON property krb5ConfigGcsUri

Returns:

  • (String)


1565
1566
1567
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1565

def krb5_config_gcs_uri
  @krb5_config_gcs_uri
end

#principalString

Optional. A Kerberos principal that exists in the both the keytab the KDC to authenticate as. A typical principal is of the form primary/instance@REALM, but there is no exact format. Corresponds to the JSON property principal

Returns:

  • (String)


1572
1573
1574
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1572

def principal
  @principal
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1579
1580
1581
1582
1583
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1579

def update!(**args)
  @keytab = args[:keytab] if args.key?(:keytab)
  @krb5_config_gcs_uri = args[:krb5_config_gcs_uri] if args.key?(:krb5_config_gcs_uri)
  @principal = args[:principal] if args.key?(:principal)
end