Class: Google::Apis::MetastoreV1alpha::LimitConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Represents the autoscaling limit configuration of a metastore service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LimitConfig

Returns a new instance of LimitConfig.



1303
1304
1305
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_scaling_factorFloat

Optional. The highest scaling factor that the service should be autoscaled to. Corresponds to the JSON property maxScalingFactor

Returns:

  • (Float)


1296
1297
1298
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1296

def max_scaling_factor
  @max_scaling_factor
end

#min_scaling_factorFloat

Optional. The lowest scaling factor that the service should be autoscaled to. Corresponds to the JSON property minScalingFactor

Returns:

  • (Float)


1301
1302
1303
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1301

def min_scaling_factor
  @min_scaling_factor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1308
1309
1310
1311
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1308

def update!(**args)
  @max_scaling_factor = args[:max_scaling_factor] if args.key?(:max_scaling_factor)
  @min_scaling_factor = args[:min_scaling_factor] if args.key?(:min_scaling_factor)
end