Class: Google::Apis::MetastoreV1alpha::MetadataIntegration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Specifies how metastore metadata should be integrated with external services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetadataIntegration

Returns a new instance of MetadataIntegration.



1779
1780
1781
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1779

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_catalog_configGoogle::Apis::MetastoreV1alpha::DataCatalogConfig

Specifies how metastore metadata should be integrated with the Data Catalog service. Corresponds to the JSON property dataCatalogConfig



1771
1772
1773
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1771

def data_catalog_config
  @data_catalog_config
end

#dataplex_configGoogle::Apis::MetastoreV1alpha::DataplexConfig

Specifies how metastore metadata should be integrated with the Dataplex service. Corresponds to the JSON property dataplexConfig



1777
1778
1779
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1777

def dataplex_config
  @dataplex_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1784
1785
1786
1787
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1784

def update!(**args)
  @data_catalog_config = args[:data_catalog_config] if args.key?(:data_catalog_config)
  @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config)
end