Class: Google::Apis::MetastoreV1alpha::MigrationExecution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

The details of a migration execution resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrationExecution

Returns a new instance of MigrationExecution.



2225
2226
2227
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#biglake_metastore_migration_configGoogle::Apis::MetastoreV1alpha::BigLakeMetastoreMigrationConfig

Defines the configuration required to migrate metadata from a Dataproc Metastore service to BigLake Metastore. Corresponds to the JSON property biglakeMetastoreMigrationConfig



2180
2181
2182
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2180

def biglake_metastore_migration_config
  @biglake_metastore_migration_config
end

#cloud_sql_migration_configGoogle::Apis::MetastoreV1alpha::CloudSqlMigrationConfig

Deprecated: Migrations to Dataproc Metastore are no longer supported. Use BigLake Metastore migration instead. Configuration information for migrating from self-managed hive metastore on Google Cloud using Cloud SQL as the backend database to Dataproc Metastore. Corresponds to the JSON property cloudSqlMigrationConfig



2188
2189
2190
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2188

def cloud_sql_migration_config
  @cloud_sql_migration_config
end

#create_timeString

Output only. The time when the migration execution was started. Corresponds to the JSON property createTime

Returns:

  • (String)


2193
2194
2195
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2193

def create_time
  @create_time
end

#end_timeString

Output only. The time when the migration execution finished. Corresponds to the JSON property endTime

Returns:

  • (String)


2198
2199
2200
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2198

def end_time
  @end_time
end

#nameString

Output only. The relative resource name of the migration execution, in the following form: projects/project_number/locations/location_id/services/ service_id/migrationExecutions/migration_execution_id Corresponds to the JSON property name

Returns:

  • (String)


2205
2206
2207
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2205

def name
  @name
end

#phaseString

Output only. Deprecated: Phase was designed for incoming migrations to Dataproc Metastore, not applicable when migrating away from it. The current phase of the migration execution. Corresponds to the JSON property phase

Returns:

  • (String)


2212
2213
2214
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2212

def phase
  @phase
end

#stateString

Output only. The current state of the migration execution. Corresponds to the JSON property state

Returns:

  • (String)


2217
2218
2219
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2217

def state
  @state
end

#state_messageString

Output only. Additional information about the current state of the migration execution. Corresponds to the JSON property stateMessage

Returns:

  • (String)


2223
2224
2225
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2223

def state_message
  @state_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2230

def update!(**args)
  @biglake_metastore_migration_config = args[:biglake_metastore_migration_config] if args.key?(:biglake_metastore_migration_config)
  @cloud_sql_migration_config = args[:cloud_sql_migration_config] if args.key?(:cloud_sql_migration_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @phase = args[:phase] if args.key?(:phase)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
end