Class: Google::Apis::MetastoreV1alpha::MoveTableToDatabaseRequest
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::MoveTableToDatabaseRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Request message for DataprocMetastore.MoveTableToDatabase.
Instance Attribute Summary collapse
-
#db_name ⇒ String
Required.
-
#destination_db_name ⇒ String
Required.
-
#table_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MoveTableToDatabaseRequest
constructor
A new instance of MoveTableToDatabaseRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MoveTableToDatabaseRequest
Returns a new instance of MoveTableToDatabaseRequest.
1893 1894 1895 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#db_name ⇒ String
Required. The name of the database where the table resides.
Corresponds to the JSON property dbName
1881 1882 1883 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1881 def db_name @db_name end |
#destination_db_name ⇒ String
Required. The name of the database where the table should be moved.
Corresponds to the JSON property destinationDbName
1886 1887 1888 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1886 def destination_db_name @destination_db_name end |
#table_name ⇒ String
Required. The name of the table to be moved.
Corresponds to the JSON property tableName
1891 1892 1893 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1891 def table_name @table_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1898 1899 1900 1901 1902 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1898 def update!(**args) @db_name = args[:db_name] if args.key?(:db_name) @destination_db_name = args[:destination_db_name] if args.key?(:destination_db_name) @table_name = args[:table_name] if args.key?(:table_name) end |