Class: Google::Apis::MetastoreV1alpha::MultiRegionMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Deprecated: Use a single region service instead. The metadata for the multi- region that includes the constituent regions. The metadata is only populated if the region is multi-region. For single region or custom dual region, it will be empty.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiRegionMetadata

Returns a new instance of MultiRegionMetadata.



2245
2246
2247
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constituent_regionsArray<String>

The regions constituting the multi-region. Corresponds to the JSON property constituentRegions

Returns:

  • (Array<String>)


2233
2234
2235
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2233

def constituent_regions
  @constituent_regions
end

#continentString

The continent for this multi-region. Corresponds to the JSON property continent

Returns:

  • (String)


2238
2239
2240
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2238

def continent
  @continent
end

#witness_regionString

The Spanner witness region for this multi-region. Corresponds to the JSON property witnessRegion

Returns:

  • (String)


2243
2244
2245
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2243

def witness_region
  @witness_region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2250
2251
2252
2253
2254
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2250

def update!(**args)
  @constituent_regions = args[:constituent_regions] if args.key?(:constituent_regions)
  @continent = args[:continent] if args.key?(:continent)
  @witness_region = args[:witness_region] if args.key?(:witness_region)
end