Class: Google::Apis::MetastoreV1alpha::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Represents the metadata of a long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



2390
2391
2392
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


2354
2355
2356
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2354

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2359
2360
2361
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2359

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


2364
2365
2366
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2364

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the caller has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


2372
2373
2374
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2372

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


2378
2379
2380
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2378

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


2383
2384
2385
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2383

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


2388
2389
2390
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2388

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2395
2396
2397
2398
2399
2400
2401
2402
2403
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2395

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end