Class: Google::Apis::MetastoreV1alpha::PartitionReport
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::PartitionReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Partition migration report for a Hive table.
Instance Attribute Summary collapse
-
#partition_failed_count ⇒ Fixnum
The number of partitions that failed to migrate at the target.
-
#partition_success_count ⇒ Fixnum
The number of partitions successfully migrated at the target.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartitionReport
constructor
A new instance of PartitionReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartitionReport
Returns a new instance of PartitionReport.
2584 2585 2586 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partition_failed_count ⇒ Fixnum
The number of partitions that failed to migrate at the target.
Corresponds to the JSON property partitionFailedCount
2572 2573 2574 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2572 def partition_failed_count @partition_failed_count end |
#partition_success_count ⇒ Fixnum
The number of partitions successfully migrated at the target.
Corresponds to the JSON property partitionSuccessCount
2577 2578 2579 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2577 def partition_success_count @partition_success_count end |
#state ⇒ String
Output only. The state of the partition migration.
Corresponds to the JSON property state
2582 2583 2584 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2582 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2589 2590 2591 2592 2593 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2589 def update!(**args) @partition_failed_count = args[:partition_failed_count] if args.key?(:partition_failed_count) @partition_success_count = args[:partition_success_count] if args.key?(:partition_success_count) @state = args[:state] if args.key?(:state) end |