Class: Google::Apis::MetastoreV1alpha::Restore
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::Restore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
The details of a metadata restore operation.
Instance Attribute Summary collapse
-
#backup ⇒ String
Output only.
-
#backup_location ⇒ String
Optional.
-
#details ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Restore
constructor
A new instance of Restore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Restore
Returns a new instance of Restore.
2815 2816 2817 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
Output only. The relative resource name of the metastore service backup to
restore from, in the following form:projects/project_id/locations/
location_id/services/service_id/backups/backup_id.
Corresponds to the JSON property backup
2781 2782 2783 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2781 def backup @backup end |
#backup_location ⇒ String
Optional. A Cloud Storage URI specifying where the backup artifacts are stored,
in the format gs:///.
Corresponds to the JSON property backupLocation
2787 2788 2789 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2787 def backup_location @backup_location end |
#details ⇒ String
Output only. The restore details containing the revision of the service to be
restored to, in format of JSON.
Corresponds to the JSON property details
2793 2794 2795 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2793 def details @details end |
#end_time ⇒ String
Output only. The time when the restore ended.
Corresponds to the JSON property endTime
2798 2799 2800 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2798 def end_time @end_time end |
#start_time ⇒ String
Output only. The time when the restore started.
Corresponds to the JSON property startTime
2803 2804 2805 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2803 def start_time @start_time end |
#state ⇒ String
Output only. The current state of the restore.
Corresponds to the JSON property state
2808 2809 2810 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2808 def state @state end |
#type ⇒ String
Output only. The type of restore.
Corresponds to the JSON property type
2813 2814 2815 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2813 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2820 2821 2822 2823 2824 2825 2826 2827 2828 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2820 def update!(**args) @backup = args[:backup] if args.key?(:backup) @backup_location = args[:backup_location] if args.key?(:backup_location) @details = args[:details] if args.key?(:details) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) end |