Class: Google::Apis::MetastoreV1alpha::StartMigrationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Request message for DataprocMetastore.StartMigration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartMigrationRequest

Returns a new instance of StartMigrationRequest.



3279
3280
3281
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3279

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#migration_executionGoogle::Apis::MetastoreV1alpha::MigrationExecution

The details of a migration execution resource. Corresponds to the JSON property migrationExecution



3265
3266
3267
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3265

def migration_execution
  @migration_execution
end

#request_idString

Optional. A request ID. Specify a unique request ID to allow the server to ignore the request if it has completed. The server will ignore subsequent requests that provide a duplicate request ID for at least 60 minutes after the first request.For example, if an initial request times out, followed by another request with the same request ID, the server ignores the second request to prevent the creation of duplicate commitments.The request ID must be a valid UUID (https://en.wikipedia.org/wiki/Universally_unique_identifier# Format) A zero UUID (00000000-0000-0000-0000-000000000000) is not supported. Corresponds to the JSON property requestId

Returns:

  • (String)


3277
3278
3279
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3277

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3284
3285
3286
3287
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3284

def update!(**args)
  @migration_execution = args[:migration_execution] if args.key?(:migration_execution)
  @request_id = args[:request_id] if args.key?(:request_id)
end