Class: Google::Apis::MetastoreV1alpha::TableSummary
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::TableSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Aggregated summary of results for all tables in a database.
Instance Attribute Summary collapse
-
#partition_discovered_count ⇒ Fixnum
Output only.
-
#partition_failed_count ⇒ Fixnum
Output only.
-
#partition_success_count ⇒ Fixnum
Output only.
-
#plan_counts ⇒ Hash<String,Fixnum>
Output only.
-
#result_counts ⇒ Hash<String,Fixnum>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TableSummary
constructor
A new instance of TableSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TableSummary
Returns a new instance of TableSummary.
3467 3468 3469 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partition_discovered_count ⇒ Fixnum
Output only. Partition migration summary across all Hive tables in the
database.The total number of partitions discovered at the source.
Corresponds to the JSON property partitionDiscoveredCount
3440 3441 3442 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3440 def partition_discovered_count @partition_discovered_count end |
#partition_failed_count ⇒ Fixnum
Output only. The total number of partitions that failed to migrate at the
target.
Corresponds to the JSON property partitionFailedCount
3446 3447 3448 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3446 def partition_failed_count @partition_failed_count end |
#partition_success_count ⇒ Fixnum
Output only. The total number of partitions successfully migrated at the
target.
Corresponds to the JSON property partitionSuccessCount
3452 3453 3454 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3452 def partition_success_count @partition_success_count end |
#plan_counts ⇒ Hash<String,Fixnum>
Output only. Number of tables with a specific migration plan action. The key
is the action name (e.g. CREATE, UPDATE, SKIP, etc.).
Corresponds to the JSON property planCounts
3458 3459 3460 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3458 def plan_counts @plan_counts end |
#result_counts ⇒ Hash<String,Fixnum>
Output only. Number of tables with a specific migration result status. The key
is the status name (e.g. SUCCEEDED, FAILED, SKIPPED, etc.). This is only set
if the migration is not a dry run.
Corresponds to the JSON property resultCounts
3465 3466 3467 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3465 def result_counts @result_counts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3472 3473 3474 3475 3476 3477 3478 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3472 def update!(**args) @partition_discovered_count = args[:partition_discovered_count] if args.key?(:partition_discovered_count) @partition_failed_count = args[:partition_failed_count] if args.key?(:partition_failed_count) @partition_success_count = args[:partition_success_count] if args.key?(:partition_success_count) @plan_counts = args[:plan_counts] if args.key?(:plan_counts) @result_counts = args[:result_counts] if args.key?(:result_counts) end |