Class: Google::Apis::MetastoreV1alpha::DatabaseSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Summary of results for a specific database in a catalog.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseSummary

Returns a new instance of DatabaseSummary.



996
997
998
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#databaseString

Output only. The name of the database. Corresponds to the JSON property database

Returns:

  • (String)


978
979
980
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 978

def database
  @database
end

#plan_actionString

Output only. The migration plan action for the database. Corresponds to the JSON property planAction

Returns:

  • (String)


983
984
985
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 983

def plan_action
  @plan_action
end

#result_statusString

Output only. The migration result status for the database. This is only set if the migration is not a dry run. Corresponds to the JSON property resultStatus

Returns:

  • (String)


989
990
991
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 989

def result_status
  @result_status
end

#table_summaryGoogle::Apis::MetastoreV1alpha::TableSummary

Aggregated summary of results for all tables in a database. Corresponds to the JSON property tableSummary



994
995
996
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 994

def table_summary
  @table_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1001
1002
1003
1004
1005
1006
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1001

def update!(**args)
  @database = args[:database] if args.key?(:database)
  @plan_action = args[:plan_action] if args.key?(:plan_action)
  @result_status = args[:result_status] if args.key?(:result_status)
  @table_summary = args[:table_summary] if args.key?(:table_summary)
end