Class: Google::Apis::MetastoreV1alpha::EncryptionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Encryption settings for the service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionConfig

Returns a new instance of EncryptionConfig.



899
900
901
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_keyString

Optional. The fully qualified customer provided Cloud KMS key name to use for customer data encryption, in the following format:projects/project_number/ locations/location_id/keyRings/key_ring_id/cryptoKeys/crypto_key_id. Corresponds to the JSON property kmsKey

Returns:

  • (String)


889
890
891
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 889

def kms_key
  @kms_key
end

#kms_keysArray<String>

Optional. The list of fully qualified customer provided Cloud KMS key names for the multi-regional service. Each key must be in the following format: projects/project_number/locations/location_id/keyRings/key_ring_id/ cryptoKeys/crypto_key_id. Corresponds to the JSON property kmsKeys

Returns:

  • (Array<String>)


897
898
899
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 897

def kms_keys
  @kms_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



904
905
906
907
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 904

def update!(**args)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @kms_keys = args[:kms_keys] if args.key?(:kms_keys)
end