Class: Google::Apis::MetastoreV1alpha::ExecutionPlan
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::ExecutionPlan
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Represents the migration plan for a specific resource (e.g. Database, Table).
Instance Attribute Summary collapse
-
#action ⇒ String
The action that will be taken for a resource during migration.
-
#diffs ⇒ Hash<String,Google::Apis::MetastoreV1alpha::ValueDiff>
A map of field names to their respective value diff.
-
#reason ⇒ String
A human-readable string explaining why the action was chosen.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecutionPlan
constructor
A new instance of ExecutionPlan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecutionPlan
Returns a new instance of ExecutionPlan.
1185 1186 1187 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
The action that will be taken for a resource during migration.
Corresponds to the JSON property action
1173 1174 1175 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1173 def action @action end |
#diffs ⇒ Hash<String,Google::Apis::MetastoreV1alpha::ValueDiff>
A map of field names to their respective value diff.
Corresponds to the JSON property diffs
1178 1179 1180 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1178 def diffs @diffs end |
#reason ⇒ String
A human-readable string explaining why the action was chosen.
Corresponds to the JSON property reason
1183 1184 1185 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1183 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1190 1191 1192 1193 1194 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1190 def update!(**args) @action = args[:action] if args.key?(:action) @diffs = args[:diffs] if args.key?(:diffs) @reason = args[:reason] if args.key?(:reason) end |