Class: Google::Apis::MetastoreV1alpha::ExecutionResult
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::ExecutionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Represents the actual migration result for a specific resource (e.g. Database, Table).
Instance Attribute Summary collapse
-
#error_message ⇒ String
Description of the error if the state is FAILED.
-
#remediation ⇒ String
Remediation steps for the error if the state is FAILED.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecutionResult
constructor
A new instance of ExecutionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecutionResult
Returns a new instance of ExecutionResult.
1217 1218 1219 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_message ⇒ String
Description of the error if the state is FAILED.
Corresponds to the JSON property errorMessage
1205 1206 1207 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1205 def @error_message end |
#remediation ⇒ String
Remediation steps for the error if the state is FAILED.
Corresponds to the JSON property remediation
1210 1211 1212 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1210 def remediation @remediation end |
#state ⇒ String
Output only. The state of the migration for a resource.
Corresponds to the JSON property state
1215 1216 1217 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1215 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1222 1223 1224 1225 1226 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1222 def update!(**args) @error_message = args[:error_message] if args.key?(:error_message) @remediation = args[:remediation] if args.key?(:remediation) @state = args[:state] if args.key?(:state) end |