Class: Google::Apis::MetastoreV1alpha::Federation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Represents a federation of multiple backend metastores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Federation

Returns a new instance of Federation.



1260
1261
1262
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_metastoresHash<String,Google::Apis::MetastoreV1alpha::BackendMetastore>

A map from BackendMetastore rank to BackendMetastores from which the federation service serves metadata at query time. The map key represents the order in which BackendMetastores should be evaluated to resolve database names at query time and should be greater than or equal to zero. A BackendMetastore with a lower number will be evaluated before a BackendMetastore with a higher number. Corresponds to the JSON property backendMetastores



1202
1203
1204
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1202

def backend_metastores
  @backend_metastores
end

#create_timeString

Output only. The time when the metastore federation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1207
1208
1209
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1207

def create_time
  @create_time
end

#endpoint_uriString

Output only. The federation endpoint. Corresponds to the JSON property endpointUri

Returns:

  • (String)


1212
1213
1214
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1212

def endpoint_uri
  @endpoint_uri
end

#labelsHash<String,String>

User-defined labels for the metastore federation. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1217
1218
1219
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1217

def labels
  @labels
end

#nameString

Immutable. The relative resource name of the federation, of the form: projects/ project_number/locations/location_id/federations/federation_id. Corresponds to the JSON propertyname`

Returns:

  • (String)


1223
1224
1225
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1223

def name
  @name
end

#stateString

Output only. The current state of the federation. Corresponds to the JSON property state

Returns:

  • (String)


1228
1229
1230
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1228

def state
  @state
end

#state_messageString

Output only. Additional information about the current state of the metastore federation, if available. Corresponds to the JSON property stateMessage

Returns:

  • (String)


1234
1235
1236
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1234

def state_message
  @state_message
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": " marketing" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


1241
1242
1243
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1241

def tags
  @tags
end

#uidString

Output only. The globally unique resource identifier of the metastore federation. Corresponds to the JSON property uid

Returns:

  • (String)


1247
1248
1249
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1247

def uid
  @uid
end

#update_timeString

Output only. The time when the metastore federation was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1252
1253
1254
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1252

def update_time
  @update_time
end

#versionString

Immutable. The Apache Hive metastore version of the federation. All backend metastore versions must be compatible with the federation version. Corresponds to the JSON property version

Returns:

  • (String)


1258
1259
1260
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1258

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1265

def update!(**args)
  @backend_metastores = args[:backend_metastores] if args.key?(:backend_metastores)
  @create_time = args[:create_time] if args.key?(:create_time)
  @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @tags = args[:tags] if args.key?(:tags)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end