Class: Google::Apis::MetastoreV1alpha::Federation
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::Federation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Represents a federation of multiple backend metastores.
Instance Attribute Summary collapse
-
#backend_metastores ⇒ Hash<String,Google::Apis::MetastoreV1alpha::BackendMetastore>
A map from BackendMetastore rank to BackendMetastores from which the federation service serves metadata at query time.
-
#create_time ⇒ String
Output only.
-
#endpoint_uri ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
User-defined labels for the metastore federation.
-
#name ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#state_message ⇒ String
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Federation
constructor
A new instance of Federation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Federation
Returns a new instance of Federation.
1097 1098 1099 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_metastores ⇒ Hash<String,Google::Apis::MetastoreV1alpha::BackendMetastore>
A map from BackendMetastore rank to BackendMetastores from which the
federation service serves metadata at query time. The map key represents the
order in which BackendMetastores should be evaluated to resolve database names
at query time and should be greater than or equal to zero. A BackendMetastore
with a lower number will be evaluated before a BackendMetastore with a higher
number.
Corresponds to the JSON property backendMetastores
1039 1040 1041 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1039 def @backend_metastores end |
#create_time ⇒ String
Output only. The time when the metastore federation was created.
Corresponds to the JSON property createTime
1044 1045 1046 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1044 def create_time @create_time end |
#endpoint_uri ⇒ String
Output only. The federation endpoint.
Corresponds to the JSON property endpointUri
1049 1050 1051 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1049 def endpoint_uri @endpoint_uri end |
#labels ⇒ Hash<String,String>
User-defined labels for the metastore federation.
Corresponds to the JSON property labels
1054 1055 1056 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1054 def labels @labels end |
#name ⇒ String
Immutable. The relative resource name of the federation, of the form: projects/
project_number/locations/location_id/federations/federation_id.
Corresponds to the JSON propertyname`
1060 1061 1062 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1060 def name @name end |
#state ⇒ String
Output only. The current state of the federation.
Corresponds to the JSON property state
1065 1066 1067 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1065 def state @state end |
#state_message ⇒ String
Output only. Additional information about the current state of the metastore
federation, if available.
Corresponds to the JSON property stateMessage
1071 1072 1073 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1071 def @state_message end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this
resource. For example: "123/environment": "production", "123/costCenter": "
marketing"
Corresponds to the JSON property tags
1078 1079 1080 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1078 def @tags end |
#uid ⇒ String
Output only. The globally unique resource identifier of the metastore
federation.
Corresponds to the JSON property uid
1084 1085 1086 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1084 def uid @uid end |
#update_time ⇒ String
Output only. The time when the metastore federation was last updated.
Corresponds to the JSON property updateTime
1089 1090 1091 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1089 def update_time @update_time end |
#version ⇒ String
Immutable. The Apache Hive metastore version of the federation. All backend
metastore versions must be compatible with the federation version.
Corresponds to the JSON property version
1095 1096 1097 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1095 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1102 def update!(**args) @backend_metastores = args[:backend_metastores] if args.key?(:backend_metastores) @create_time = args[:create_time] if args.key?(:create_time) @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @tags = args[:tags] if args.key?(:tags) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |