Class: Google::Apis::MetastoreV1alpha::HiveConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Configuration for migrating Hive metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HiveConfig

Returns a new instance of HiveConfig.



1297
1298
1299
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catalogString

Required. The target catalog for migrated databases and tables. Format: " projects/project_id_or_number/catalogs/catalog_id" Corresponds to the JSON property catalog

Returns:

  • (String)


1288
1289
1290
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1288

def catalog
  @catalog
end

#databasesArray<String>

Required. The list of databases to migrate to the Hive catalog. Use "*" to migrate all databases. Note: If Iceberg tables exist in these databases, they will only be migrated if iceberg_config is also specified. Corresponds to the JSON property databases

Returns:

  • (Array<String>)


1295
1296
1297
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1295

def databases
  @databases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1302
1303
1304
1305
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1302

def update!(**args)
  @catalog = args[:catalog] if args.key?(:catalog)
  @databases = args[:databases] if args.key?(:databases)
end