Class: Google::Apis::MetastoreV1alpha::LocationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::LocationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Metadata about the service in a location.
Instance Attribute Summary collapse
-
#custom_region_metadata ⇒ Array<Google::Apis::MetastoreV1alpha::CustomRegionMetadata>
Deprecated: Use a single region service instead.
-
#multi_region_metadata ⇒ Google::Apis::MetastoreV1alpha::MultiRegionMetadata
Deprecated: Use a single region service instead.
-
#supported_hive_metastore_versions ⇒ Array<Google::Apis::MetastoreV1alpha::HiveMetastoreVersion>
The versions of Hive Metastore that can be used when creating a new metastore service in this location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocationMetadata
constructor
A new instance of LocationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocationMetadata
Returns a new instance of LocationMetadata.
1608 1609 1610 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_region_metadata ⇒ Array<Google::Apis::MetastoreV1alpha::CustomRegionMetadata>
Deprecated: Use a single region service instead. Possible configurations
supported if the current region is a custom region.
Corresponds to the JSON property customRegionMetadata
1591 1592 1593 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1591 def @custom_region_metadata end |
#multi_region_metadata ⇒ Google::Apis::MetastoreV1alpha::MultiRegionMetadata
Deprecated: Use a single region service instead. The metadata for the multi-
region that includes the constituent regions. The metadata is only populated
if the region is multi-region. For single region or custom dual region, it
will be empty.
Corresponds to the JSON property multiRegionMetadata
1599 1600 1601 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1599 def @multi_region_metadata end |
#supported_hive_metastore_versions ⇒ Array<Google::Apis::MetastoreV1alpha::HiveMetastoreVersion>
The versions of Hive Metastore that can be used when creating a new metastore
service in this location. The server guarantees that exactly one
HiveMetastoreVersion in the list will set is_default.
Corresponds to the JSON property supportedHiveMetastoreVersions
1606 1607 1608 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1606 def @supported_hive_metastore_versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1613 1614 1615 1616 1617 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1613 def update!(**args) @custom_region_metadata = args[:custom_region_metadata] if args.key?(:custom_region_metadata) @multi_region_metadata = args[:multi_region_metadata] if args.key?(:multi_region_metadata) @supported_hive_metastore_versions = args[:supported_hive_metastore_versions] if args.key?(:supported_hive_metastore_versions) end |