Class: Google::Apis::MetastoreV1alpha::MetadataImport
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::MetadataImport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
A metastore resource that imports metadata.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#database_dump ⇒ Google::Apis::MetastoreV1alpha::DatabaseDump
A specification of the location of and metadata about a database dump from a relational database management system.
-
#description ⇒ String
Optional.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetadataImport
constructor
A new instance of MetadataImport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetadataImport
Returns a new instance of MetadataImport.
2104 2105 2106 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the metadata import was started.
Corresponds to the JSON property createTime
2069 2070 2071 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2069 def create_time @create_time end |
#database_dump ⇒ Google::Apis::MetastoreV1alpha::DatabaseDump
A specification of the location of and metadata about a database dump from a
relational database management system.
Corresponds to the JSON property databaseDump
2075 2076 2077 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2075 def database_dump @database_dump end |
#description ⇒ String
Optional. The description of the metadata import.
Corresponds to the JSON property description
2080 2081 2082 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2080 def description @description end |
#end_time ⇒ String
Output only. The time when the metadata import finished.
Corresponds to the JSON property endTime
2085 2086 2087 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2085 def end_time @end_time end |
#name ⇒ String
Immutable. Identifier. The relative resource name of the metadata import, of
the form:projects/project_number/locations/location_id/services/
service_id/metadataImports/metadata_import_id.
Corresponds to the JSON property name
2092 2093 2094 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2092 def name @name end |
#state ⇒ String
Output only. The current state of the metadata import.
Corresponds to the JSON property state
2097 2098 2099 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2097 def state @state end |
#update_time ⇒ String
Output only. The time when the metadata import was last updated.
Corresponds to the JSON property updateTime
2102 2103 2104 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2102 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2109 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @database_dump = args[:database_dump] if args.key?(:database_dump) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |