Class: Google::Apis::MetastoreV1alpha::MigrationExecution
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::MigrationExecution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
The details of a migration execution resource.
Instance Attribute Summary collapse
-
#cloud_sql_migration_config ⇒ Google::Apis::MetastoreV1alpha::CloudSqlMigrationConfig
Deprecated: Migrations to Dataproc Metastore are no longer supported.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#phase ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#state_message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrationExecution
constructor
A new instance of MigrationExecution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrationExecution
Returns a new instance of MigrationExecution.
1868 1869 1870 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_sql_migration_config ⇒ Google::Apis::MetastoreV1alpha::CloudSqlMigrationConfig
Deprecated: Migrations to Dataproc Metastore are no longer supported. Use
BigLake Metastore migration instead. Configuration information for migrating
from self-managed hive metastore on Google Cloud using Cloud SQL as the
backend database to Dataproc Metastore.
Corresponds to the JSON property cloudSqlMigrationConfig
1831 1832 1833 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1831 def cloud_sql_migration_config @cloud_sql_migration_config end |
#create_time ⇒ String
Output only. The time when the migration execution was started.
Corresponds to the JSON property createTime
1836 1837 1838 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1836 def create_time @create_time end |
#end_time ⇒ String
Output only. The time when the migration execution finished.
Corresponds to the JSON property endTime
1841 1842 1843 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1841 def end_time @end_time end |
#name ⇒ String
Output only. The relative resource name of the migration execution, in the
following form: projects/project_number/locations/location_id/services/
service_id/migrationExecutions/migration_execution_id
Corresponds to the JSON property name
1848 1849 1850 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1848 def name @name end |
#phase ⇒ String
Output only. Deprecated: Phase was designed for incoming migrations to
Dataproc Metastore, not applicable when migrating away from it. The current
phase of the migration execution.
Corresponds to the JSON property phase
1855 1856 1857 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1855 def phase @phase end |
#state ⇒ String
Output only. The current state of the migration execution.
Corresponds to the JSON property state
1860 1861 1862 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1860 def state @state end |
#state_message ⇒ String
Output only. Additional information about the current state of the migration
execution.
Corresponds to the JSON property stateMessage
1866 1867 1868 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1866 def @state_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1873 1874 1875 1876 1877 1878 1879 1880 1881 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1873 def update!(**args) @cloud_sql_migration_config = args[:cloud_sql_migration_config] if args.key?(:cloud_sql_migration_config) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @phase = args[:phase] if args.key?(:phase) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) end |