Class: Google::Apis::MetastoreV1alpha::MigrationExecution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

The details of a migration execution resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrationExecution

Returns a new instance of MigrationExecution.



1858
1859
1860
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_sql_migration_configGoogle::Apis::MetastoreV1alpha::CloudSqlMigrationConfig

Configuration information for migrating from self-managed hive metastore on Google Cloud using Cloud SQL as the backend database to Dataproc Metastore. Corresponds to the JSON property cloudSqlMigrationConfig



1823
1824
1825
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1823

def cloud_sql_migration_config
  @cloud_sql_migration_config
end

#create_timeString

Output only. The time when the migration execution was started. Corresponds to the JSON property createTime

Returns:

  • (String)


1828
1829
1830
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1828

def create_time
  @create_time
end

#end_timeString

Output only. The time when the migration execution finished. Corresponds to the JSON property endTime

Returns:

  • (String)


1833
1834
1835
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1833

def end_time
  @end_time
end

#nameString

Output only. The relative resource name of the migration execution, in the following form: projects/project_number/locations/location_id/services/ service_id/migrationExecutions/migration_execution_id Corresponds to the JSON property name

Returns:

  • (String)


1840
1841
1842
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1840

def name
  @name
end

#phaseString

Output only. The current phase of the migration execution. Corresponds to the JSON property phase

Returns:

  • (String)


1845
1846
1847
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1845

def phase
  @phase
end

#stateString

Output only. The current state of the migration execution. Corresponds to the JSON property state

Returns:

  • (String)


1850
1851
1852
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1850

def state
  @state
end

#state_messageString

Output only. Additional information about the current state of the migration execution. Corresponds to the JSON property stateMessage

Returns:

  • (String)


1856
1857
1858
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1856

def state_message
  @state_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1863
1864
1865
1866
1867
1868
1869
1870
1871
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1863

def update!(**args)
  @cloud_sql_migration_config = args[:cloud_sql_migration_config] if args.key?(:cloud_sql_migration_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @phase = args[:phase] if args.key?(:phase)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
end