Class: Google::Apis::MetastoreV1alpha::MigrationReport
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::MigrationReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Report containing the results of a migration run. This report is generated at the specified path in the BigLakeMetastoreMigrationConfig after the backfill is complete, or when a dry run is executed.
Instance Attribute Summary collapse
-
#catalog_reports ⇒ Array<Google::Apis::MetastoreV1alpha::CatalogReport>
Output only.
-
#summary ⇒ Google::Apis::MetastoreV1alpha::MigrationSummary
Summary of the migration results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrationReport
constructor
A new instance of MigrationReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrationReport
Returns a new instance of MigrationReport.
2258 2259 2260 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog_reports ⇒ Array<Google::Apis::MetastoreV1alpha::CatalogReport>
Output only. Detailed results for each catalog involved in the migration.
Corresponds to the JSON property catalogReports
2251 2252 2253 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2251 def catalog_reports @catalog_reports end |
#summary ⇒ Google::Apis::MetastoreV1alpha::MigrationSummary
Summary of the migration results.
Corresponds to the JSON property summary
2256 2257 2258 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2256 def summary @summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2263 2264 2265 2266 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2263 def update!(**args) @catalog_reports = args[:catalog_reports] if args.key?(:catalog_reports) @summary = args[:summary] if args.key?(:summary) end |