Class: Google::Apis::MetastoreV1alpha::MultiRegionMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Deprecated: Use a single region service instead. The metadata for the multi- region that includes the constituent regions. The metadata is only populated if the region is multi-region. For single region or custom dual region, it will be empty.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiRegionMetadata

Returns a new instance of MultiRegionMetadata.



1980
1981
1982
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constituent_regionsArray<String>

The regions constituting the multi-region. Corresponds to the JSON property constituentRegions

Returns:

  • (Array<String>)


1968
1969
1970
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1968

def constituent_regions
  @constituent_regions
end

#continentString

The continent for this multi-region. Corresponds to the JSON property continent

Returns:

  • (String)


1973
1974
1975
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1973

def continent
  @continent
end

#witness_regionString

The Spanner witness region for this multi-region. Corresponds to the JSON property witnessRegion

Returns:

  • (String)


1978
1979
1980
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1978

def witness_region
  @witness_region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1985
1986
1987
1988
1989
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 1985

def update!(**args)
  @constituent_regions = args[:constituent_regions] if args.key?(:constituent_regions)
  @continent = args[:continent] if args.key?(:continent)
  @witness_region = args[:witness_region] if args.key?(:witness_region)
end