Class: Google::Apis::MetastoreV1alpha::Restore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

The details of a metadata restore operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Restore

Returns a new instance of Restore.



2346
2347
2348
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

Output only. The relative resource name of the metastore service backup to restore from, in the following form:projects/project_id/locations/ location_id/services/service_id/backups/backup_id. Corresponds to the JSON property backup

Returns:

  • (String)


2312
2313
2314
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2312

def backup
  @backup
end

#backup_locationString

Optional. A Cloud Storage URI specifying where the backup artifacts are stored, in the format gs:///. Corresponds to the JSON property backupLocation

Returns:

  • (String)


2318
2319
2320
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2318

def backup_location
  @backup_location
end

#detailsString

Output only. The restore details containing the revision of the service to be restored to, in format of JSON. Corresponds to the JSON property details

Returns:

  • (String)


2324
2325
2326
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2324

def details
  @details
end

#end_timeString

Output only. The time when the restore ended. Corresponds to the JSON property endTime

Returns:

  • (String)


2329
2330
2331
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2329

def end_time
  @end_time
end

#start_timeString

Output only. The time when the restore started. Corresponds to the JSON property startTime

Returns:

  • (String)


2334
2335
2336
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2334

def start_time
  @start_time
end

#stateString

Output only. The current state of the restore. Corresponds to the JSON property state

Returns:

  • (String)


2339
2340
2341
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2339

def state
  @state
end

#typeString

Output only. The type of restore. Corresponds to the JSON property type

Returns:

  • (String)


2344
2345
2346
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2344

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2351
2352
2353
2354
2355
2356
2357
2358
2359
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2351

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @backup_location = args[:backup_location] if args.key?(:backup_location)
  @details = args[:details] if args.key?(:details)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end