Class: Google::Apis::MetastoreV1alpha::RestoreServiceRequest
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::RestoreServiceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Request message for DataprocMetastore.RestoreService.
Instance Attribute Summary collapse
-
#backup ⇒ String
Optional.
-
#backup_location ⇒ String
Optional.
-
#request_id ⇒ String
Optional.
-
#restore_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestoreServiceRequest
constructor
A new instance of RestoreServiceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestoreServiceRequest
Returns a new instance of RestoreServiceRequest.
2678 2679 2680 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
Optional. The relative resource name of the metastore service backup to
restore from, in the following form:projects/project_id/locations/
location_id/services/service_id/backups/backup_id. Mutually exclusive
with backup_location, and exactly one of the two must be set.
Corresponds to the JSON property backup
2651 2652 2653 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2651 def backup @backup end |
#backup_location ⇒ String
Optional. A Cloud Storage URI specifying the location of the backup artifacts,
namely - backup avro files under "avro/", backup_metastore.json and service.
json, in the following form:gs://. Mutually exclusive with backup, and exactly
one of the two must be set.
Corresponds to the JSON property backupLocation
2659 2660 2661 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2659 def backup_location @backup_location end |
#request_id ⇒ String
Optional. A request ID. Specify a unique request ID to allow the server to
ignore the request if it has completed. The server will ignore subsequent
requests that provide a duplicate request ID for at least 60 minutes after the
first request.For example, if an initial request times out, followed by
another request with the same request ID, the server ignores the second
request to prevent the creation of duplicate commitments.The request ID must
be a valid UUID (https://en.wikipedia.org/wiki/Universally_unique_identifier#
Format). A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
Corresponds to the JSON property requestId
2671 2672 2673 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2671 def request_id @request_id end |
#restore_type ⇒ String
Optional. The type of restore. If unspecified, defaults to METADATA_ONLY.
Corresponds to the JSON property restoreType
2676 2677 2678 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2676 def restore_type @restore_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2683 2684 2685 2686 2687 2688 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2683 def update!(**args) @backup = args[:backup] if args.key?(:backup) @backup_location = args[:backup_location] if args.key?(:backup_location) @request_id = args[:request_id] if args.key?(:request_id) @restore_type = args[:restore_type] if args.key?(:restore_type) end |