Class: Google::Apis::MetastoreV1alpha::RestoreServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

Request message for DataprocMetastore.RestoreService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreServiceRequest

Returns a new instance of RestoreServiceRequest.



2413
2414
2415
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

Optional. The relative resource name of the metastore service backup to restore from, in the following form:projects/project_id/locations/ location_id/services/service_id/backups/backup_id. Mutually exclusive with backup_location, and exactly one of the two must be set. Corresponds to the JSON property backup

Returns:

  • (String)


2386
2387
2388
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2386

def backup
  @backup
end

#backup_locationString

Optional. A Cloud Storage URI specifying the location of the backup artifacts, namely - backup avro files under "avro/", backup_metastore.json and service. json, in the following form:gs://. Mutually exclusive with backup, and exactly one of the two must be set. Corresponds to the JSON property backupLocation

Returns:

  • (String)


2394
2395
2396
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2394

def backup_location
  @backup_location
end

#request_idString

Optional. A request ID. Specify a unique request ID to allow the server to ignore the request if it has completed. The server will ignore subsequent requests that provide a duplicate request ID for at least 60 minutes after the first request.For example, if an initial request times out, followed by another request with the same request ID, the server ignores the second request to prevent the creation of duplicate commitments.The request ID must be a valid UUID (https://en.wikipedia.org/wiki/Universally_unique_identifier# Format). A zero UUID (00000000-0000-0000-0000-000000000000) is not supported. Corresponds to the JSON property requestId

Returns:

  • (String)


2406
2407
2408
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2406

def request_id
  @request_id
end

#restore_typeString

Optional. The type of restore. If unspecified, defaults to METADATA_ONLY. Corresponds to the JSON property restoreType

Returns:

  • (String)


2411
2412
2413
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2411

def restore_type
  @restore_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2418
2419
2420
2421
2422
2423
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2418

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @backup_location = args[:backup_location] if args.key?(:backup_location)
  @request_id = args[:request_id] if args.key?(:request_id)
  @restore_type = args[:restore_type] if args.key?(:restore_type)
end