Class: Google::Apis::MetastoreV1alpha::Service
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
A managed metastore service that serves metadata queries.
Instance Attribute Summary collapse
-
#artifact_gcs_uri ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#database_type ⇒ String
Immutable.
-
#deletion_protection ⇒ Boolean
(also: #deletion_protection?)
Optional.
-
#encryption_config ⇒ Google::Apis::MetastoreV1alpha::EncryptionConfig
Encryption settings for the service.
-
#endpoint_uri ⇒ String
Output only.
-
#hive_metastore_config ⇒ Google::Apis::MetastoreV1alpha::HiveMetastoreConfig
Specifies configuration information specific to running Hive metastore software as the metastore service.
-
#labels ⇒ Hash<String,String>
User-defined labels for the metastore service.
-
#maintenance_window ⇒ Google::Apis::MetastoreV1alpha::MaintenanceWindow
Maintenance window.
-
#metadata_integration ⇒ Google::Apis::MetastoreV1alpha::MetadataIntegration
Specifies how metastore metadata should be integrated with external services.
-
#metadata_management_activity ⇒ Google::Apis::MetastoreV1alpha::MetadataManagementActivity
The metadata management activities of the metastore service.
-
#multi_region_config ⇒ Google::Apis::MetastoreV1alpha::MultiRegionConfig
Deprecated: Use a single region service instead.
-
#name ⇒ String
Immutable.
-
#network ⇒ String
Immutable.
-
#network_config ⇒ Google::Apis::MetastoreV1alpha::NetworkConfig
Network configuration for the Dataproc Metastore service.
-
#port ⇒ Fixnum
Optional.
-
#release_channel ⇒ String
Immutable.
-
#scaling_config ⇒ Google::Apis::MetastoreV1alpha::ScalingConfig
Represents the scaling configuration of a metastore service.
-
#scheduled_backup ⇒ Google::Apis::MetastoreV1alpha::ScheduledBackup
This specifies the configuration of scheduled backup.
-
#state ⇒ String
Output only.
-
#state_message ⇒ String
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
-
#telemetry_config ⇒ Google::Apis::MetastoreV1alpha::TelemetryConfig
Telemetry Configuration for the Dataproc Metastore service.
-
#tier ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Service
constructor
A new instance of Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Service
Returns a new instance of Service.
3170 3171 3172 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_gcs_uri ⇒ String
Output only. A Cloud Storage URI (starting with gs://) that specifies where
artifacts related to the metastore service are stored.
Corresponds to the JSON property artifactGcsUri
3029 3030 3031 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3029 def artifact_gcs_uri @artifact_gcs_uri end |
#create_time ⇒ String
Output only. The time when the metastore service was created.
Corresponds to the JSON property createTime
3034 3035 3036 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3034 def create_time @create_time end |
#database_type ⇒ String
Immutable. The database type that the Metastore service stores its data.
Corresponds to the JSON property databaseType
3039 3040 3041 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3039 def database_type @database_type end |
#deletion_protection ⇒ Boolean Also known as: deletion_protection?
Optional. Indicates if the dataproc metastore should be protected against
accidental deletions.
Corresponds to the JSON property deletionProtection
3045 3046 3047 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3045 def deletion_protection @deletion_protection end |
#encryption_config ⇒ Google::Apis::MetastoreV1alpha::EncryptionConfig
Encryption settings for the service.
Corresponds to the JSON property encryptionConfig
3051 3052 3053 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3051 def encryption_config @encryption_config end |
#endpoint_uri ⇒ String
Output only. The URI of the endpoint used to access the metastore service.
Corresponds to the JSON property endpointUri
3056 3057 3058 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3056 def endpoint_uri @endpoint_uri end |
#hive_metastore_config ⇒ Google::Apis::MetastoreV1alpha::HiveMetastoreConfig
Specifies configuration information specific to running Hive metastore
software as the metastore service.
Corresponds to the JSON property hiveMetastoreConfig
3062 3063 3064 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3062 def @hive_metastore_config end |
#labels ⇒ Hash<String,String>
User-defined labels for the metastore service.
Corresponds to the JSON property labels
3067 3068 3069 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3067 def labels @labels end |
#maintenance_window ⇒ Google::Apis::MetastoreV1alpha::MaintenanceWindow
Maintenance window. This specifies when Dataproc Metastore may perform system
maintenance operation to the service.
Corresponds to the JSON property maintenanceWindow
3073 3074 3075 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3073 def maintenance_window @maintenance_window end |
#metadata_integration ⇒ Google::Apis::MetastoreV1alpha::MetadataIntegration
Specifies how metastore metadata should be integrated with external services.
Corresponds to the JSON property metadataIntegration
3078 3079 3080 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3078 def @metadata_integration end |
#metadata_management_activity ⇒ Google::Apis::MetastoreV1alpha::MetadataManagementActivity
The metadata management activities of the metastore service.
Corresponds to the JSON property metadataManagementActivity
3083 3084 3085 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3083 def @metadata_management_activity end |
#multi_region_config ⇒ Google::Apis::MetastoreV1alpha::MultiRegionConfig
Deprecated: Use a single region service instead. The multi-region config for
the Dataproc Metastore service.
Corresponds to the JSON property multiRegionConfig
3089 3090 3091 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3089 def multi_region_config @multi_region_config end |
#name ⇒ String
Immutable. Identifier. The relative resource name of the metastore service, in
the following format:projects/project_number/locations/location_id/
services/service_id.
Corresponds to the JSON property name
3096 3097 3098 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3096 def name @name end |
#network ⇒ String
Immutable. The relative resource name of the VPC network on which the instance
can be accessed. It is specified in the following form:projects/
project_number/global/networks/network_id.
Corresponds to the JSON property network
3103 3104 3105 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3103 def network @network end |
#network_config ⇒ Google::Apis::MetastoreV1alpha::NetworkConfig
Network configuration for the Dataproc Metastore service.
Corresponds to the JSON property networkConfig
3108 3109 3110 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3108 def network_config @network_config end |
#port ⇒ Fixnum
Optional. The TCP port at which the metastore service is reached. Default:
9083.
Corresponds to the JSON property port
3114 3115 3116 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3114 def port @port end |
#release_channel ⇒ String
Immutable. The release channel of the service. If unspecified, defaults to
STABLE.
Corresponds to the JSON property releaseChannel
3120 3121 3122 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3120 def release_channel @release_channel end |
#scaling_config ⇒ Google::Apis::MetastoreV1alpha::ScalingConfig
Represents the scaling configuration of a metastore service.
Corresponds to the JSON property scalingConfig
3125 3126 3127 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3125 def scaling_config @scaling_config end |
#scheduled_backup ⇒ Google::Apis::MetastoreV1alpha::ScheduledBackup
This specifies the configuration of scheduled backup.
Corresponds to the JSON property scheduledBackup
3130 3131 3132 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3130 def scheduled_backup @scheduled_backup end |
#state ⇒ String
Output only. The current state of the metastore service.
Corresponds to the JSON property state
3135 3136 3137 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3135 def state @state end |
#state_message ⇒ String
Output only. Additional information about the current state of the metastore
service, if available.
Corresponds to the JSON property stateMessage
3141 3142 3143 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3141 def @state_message end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this
resource. For example: "123/environment": "production", "123/costCenter": "
marketing"
Corresponds to the JSON property tags
3148 3149 3150 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3148 def @tags end |
#telemetry_config ⇒ Google::Apis::MetastoreV1alpha::TelemetryConfig
Telemetry Configuration for the Dataproc Metastore service.
Corresponds to the JSON property telemetryConfig
3153 3154 3155 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3153 def telemetry_config @telemetry_config end |
#tier ⇒ String
Optional. The tier of the service.
Corresponds to the JSON property tier
3158 3159 3160 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3158 def tier @tier end |
#uid ⇒ String
Output only. The globally unique resource identifier of the metastore service.
Corresponds to the JSON property uid
3163 3164 3165 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3163 def uid @uid end |
#update_time ⇒ String
Output only. The time when the metastore service was last updated.
Corresponds to the JSON property updateTime
3168 3169 3170 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3168 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3175 3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3175 def update!(**args) @artifact_gcs_uri = args[:artifact_gcs_uri] if args.key?(:artifact_gcs_uri) @create_time = args[:create_time] if args.key?(:create_time) @database_type = args[:database_type] if args.key?(:database_type) @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri) @hive_metastore_config = args[:hive_metastore_config] if args.key?(:hive_metastore_config) @labels = args[:labels] if args.key?(:labels) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @metadata_integration = args[:metadata_integration] if args.key?(:metadata_integration) @metadata_management_activity = args[:metadata_management_activity] if args.key?(:metadata_management_activity) @multi_region_config = args[:multi_region_config] if args.key?(:multi_region_config) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_config = args[:network_config] if args.key?(:network_config) @port = args[:port] if args.key?(:port) @release_channel = args[:release_channel] if args.key?(:release_channel) @scaling_config = args[:scaling_config] if args.key?(:scaling_config) @scheduled_backup = args[:scheduled_backup] if args.key?(:scheduled_backup) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @tags = args[:tags] if args.key?(:tags) @telemetry_config = args[:telemetry_config] if args.key?(:telemetry_config) @tier = args[:tier] if args.key?(:tier) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |