Class: Google::Apis::MetastoreV1alpha::Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb

Overview

A managed metastore service that serves metadata queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



2715
2716
2717
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_gcs_uriString

Output only. A Cloud Storage URI (starting with gs://) that specifies where artifacts related to the metastore service are stored. Corresponds to the JSON property artifactGcsUri

Returns:

  • (String)


2574
2575
2576
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2574

def artifact_gcs_uri
  @artifact_gcs_uri
end

#create_timeString

Output only. The time when the metastore service was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2579
2580
2581
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2579

def create_time
  @create_time
end

#database_typeString

Immutable. The database type that the Metastore service stores its data. Corresponds to the JSON property databaseType

Returns:

  • (String)


2584
2585
2586
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2584

def database_type
  @database_type
end

#deletion_protectionBoolean Also known as: deletion_protection?

Optional. Indicates if the dataproc metastore should be protected against accidental deletions. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


2590
2591
2592
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2590

def deletion_protection
  @deletion_protection
end

#encryption_configGoogle::Apis::MetastoreV1alpha::EncryptionConfig

Encryption settings for the service. Corresponds to the JSON property encryptionConfig



2596
2597
2598
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2596

def encryption_config
  @encryption_config
end

#endpoint_uriString

Output only. The URI of the endpoint used to access the metastore service. Corresponds to the JSON property endpointUri

Returns:

  • (String)


2601
2602
2603
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2601

def endpoint_uri
  @endpoint_uri
end

#hive_metastore_configGoogle::Apis::MetastoreV1alpha::HiveMetastoreConfig

Specifies configuration information specific to running Hive metastore software as the metastore service. Corresponds to the JSON property hiveMetastoreConfig



2607
2608
2609
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2607

def hive_metastore_config
  @hive_metastore_config
end

#labelsHash<String,String>

User-defined labels for the metastore service. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2612
2613
2614
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2612

def labels
  @labels
end

#maintenance_windowGoogle::Apis::MetastoreV1alpha::MaintenanceWindow

Maintenance window. This specifies when Dataproc Metastore may perform system maintenance operation to the service. Corresponds to the JSON property maintenanceWindow



2618
2619
2620
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2618

def maintenance_window
  @maintenance_window
end

#metadata_integrationGoogle::Apis::MetastoreV1alpha::MetadataIntegration

Specifies how metastore metadata should be integrated with external services. Corresponds to the JSON property metadataIntegration



2623
2624
2625
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2623

def 
  @metadata_integration
end

#metadata_management_activityGoogle::Apis::MetastoreV1alpha::MetadataManagementActivity

The metadata management activities of the metastore service. Corresponds to the JSON property metadataManagementActivity



2628
2629
2630
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2628

def 
  @metadata_management_activity
end

#multi_region_configGoogle::Apis::MetastoreV1alpha::MultiRegionConfig

Deprecated: Use a single region service instead. The multi-region config for the Dataproc Metastore service. Corresponds to the JSON property multiRegionConfig



2634
2635
2636
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2634

def multi_region_config
  @multi_region_config
end

#nameString

Immutable. Identifier. The relative resource name of the metastore service, in the following format:projects/project_number/locations/location_id/ services/service_id. Corresponds to the JSON property name

Returns:

  • (String)


2641
2642
2643
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2641

def name
  @name
end

#networkString

Immutable. The relative resource name of the VPC network on which the instance can be accessed. It is specified in the following form:projects/ project_number/global/networks/network_id. Corresponds to the JSON property network

Returns:

  • (String)


2648
2649
2650
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2648

def network
  @network
end

#network_configGoogle::Apis::MetastoreV1alpha::NetworkConfig

Network configuration for the Dataproc Metastore service. Corresponds to the JSON property networkConfig



2653
2654
2655
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2653

def network_config
  @network_config
end

#portFixnum

Optional. The TCP port at which the metastore service is reached. Default: 9083. Corresponds to the JSON property port

Returns:

  • (Fixnum)


2659
2660
2661
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2659

def port
  @port
end

#release_channelString

Immutable. The release channel of the service. If unspecified, defaults to STABLE. Corresponds to the JSON property releaseChannel

Returns:

  • (String)


2665
2666
2667
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2665

def release_channel
  @release_channel
end

#scaling_configGoogle::Apis::MetastoreV1alpha::ScalingConfig

Represents the scaling configuration of a metastore service. Corresponds to the JSON property scalingConfig



2670
2671
2672
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2670

def scaling_config
  @scaling_config
end

#scheduled_backupGoogle::Apis::MetastoreV1alpha::ScheduledBackup

This specifies the configuration of scheduled backup. Corresponds to the JSON property scheduledBackup



2675
2676
2677
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2675

def scheduled_backup
  @scheduled_backup
end

#stateString

Output only. The current state of the metastore service. Corresponds to the JSON property state

Returns:

  • (String)


2680
2681
2682
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2680

def state
  @state
end

#state_messageString

Output only. Additional information about the current state of the metastore service, if available. Corresponds to the JSON property stateMessage

Returns:

  • (String)


2686
2687
2688
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2686

def state_message
  @state_message
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": " marketing" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


2693
2694
2695
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2693

def tags
  @tags
end

#telemetry_configGoogle::Apis::MetastoreV1alpha::TelemetryConfig

Telemetry Configuration for the Dataproc Metastore service. Corresponds to the JSON property telemetryConfig



2698
2699
2700
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2698

def telemetry_config
  @telemetry_config
end

#tierString

Optional. The tier of the service. Corresponds to the JSON property tier

Returns:

  • (String)


2703
2704
2705
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2703

def tier
  @tier
end

#uidString

Output only. The globally unique resource identifier of the metastore service. Corresponds to the JSON property uid

Returns:

  • (String)


2708
2709
2710
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2708

def uid
  @uid
end

#update_timeString

Output only. The time when the metastore service was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2713
2714
2715
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2713

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2720

def update!(**args)
  @artifact_gcs_uri = args[:artifact_gcs_uri] if args.key?(:artifact_gcs_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @database_type = args[:database_type] if args.key?(:database_type)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri)
  @hive_metastore_config = args[:hive_metastore_config] if args.key?(:hive_metastore_config)
  @labels = args[:labels] if args.key?(:labels)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @metadata_integration = args[:metadata_integration] if args.key?(:metadata_integration)
  @metadata_management_activity = args[:metadata_management_activity] if args.key?(:metadata_management_activity)
  @multi_region_config = args[:multi_region_config] if args.key?(:multi_region_config)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_config = args[:network_config] if args.key?(:network_config)
  @port = args[:port] if args.key?(:port)
  @release_channel = args[:release_channel] if args.key?(:release_channel)
  @scaling_config = args[:scaling_config] if args.key?(:scaling_config)
  @scheduled_backup = args[:scheduled_backup] if args.key?(:scheduled_backup)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @tags = args[:tags] if args.key?(:tags)
  @telemetry_config = args[:telemetry_config] if args.key?(:telemetry_config)
  @tier = args[:tier] if args.key?(:tier)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end