Class: Google::Apis::MetastoreV1alpha::Service
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
A managed metastore service that serves metadata queries.
Instance Attribute Summary collapse
-
#artifact_gcs_uri ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#database_type ⇒ String
Immutable.
-
#deletion_protection ⇒ Boolean
(also: #deletion_protection?)
Optional.
-
#encryption_config ⇒ Google::Apis::MetastoreV1alpha::EncryptionConfig
Encryption settings for the service.
-
#endpoint_uri ⇒ String
Output only.
-
#hive_metastore_config ⇒ Google::Apis::MetastoreV1alpha::HiveMetastoreConfig
Specifies configuration information specific to running Hive metastore software as the metastore service.
-
#labels ⇒ Hash<String,String>
User-defined labels for the metastore service.
-
#maintenance_window ⇒ Google::Apis::MetastoreV1alpha::MaintenanceWindow
Maintenance window.
-
#metadata_integration ⇒ Google::Apis::MetastoreV1alpha::MetadataIntegration
Specifies how metastore metadata should be integrated with external services.
-
#metadata_management_activity ⇒ Google::Apis::MetastoreV1alpha::MetadataManagementActivity
The metadata management activities of the metastore service.
-
#multi_region_config ⇒ Google::Apis::MetastoreV1alpha::MultiRegionConfig
The multi-region config for the Dataproc Metastore service.
-
#name ⇒ String
Immutable.
-
#network ⇒ String
Immutable.
-
#network_config ⇒ Google::Apis::MetastoreV1alpha::NetworkConfig
Network configuration for the Dataproc Metastore service.
-
#port ⇒ Fixnum
Optional.
-
#release_channel ⇒ String
Immutable.
-
#scaling_config ⇒ Google::Apis::MetastoreV1alpha::ScalingConfig
Represents the scaling configuration of a metastore service.
-
#scheduled_backup ⇒ Google::Apis::MetastoreV1alpha::ScheduledBackup
This specifies the configuration of scheduled backup.
-
#state ⇒ String
Output only.
-
#state_message ⇒ String
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
-
#telemetry_config ⇒ Google::Apis::MetastoreV1alpha::TelemetryConfig
Telemetry Configuration for the Dataproc Metastore service.
-
#tier ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Service
constructor
A new instance of Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Service
Returns a new instance of Service.
2697 2698 2699 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_gcs_uri ⇒ String
Output only. A Cloud Storage URI (starting with gs://) that specifies where
artifacts related to the metastore service are stored.
Corresponds to the JSON property artifactGcsUri
2557 2558 2559 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2557 def artifact_gcs_uri @artifact_gcs_uri end |
#create_time ⇒ String
Output only. The time when the metastore service was created.
Corresponds to the JSON property createTime
2562 2563 2564 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2562 def create_time @create_time end |
#database_type ⇒ String
Immutable. The database type that the Metastore service stores its data.
Corresponds to the JSON property databaseType
2567 2568 2569 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2567 def database_type @database_type end |
#deletion_protection ⇒ Boolean Also known as: deletion_protection?
Optional. Indicates if the dataproc metastore should be protected against
accidental deletions.
Corresponds to the JSON property deletionProtection
2573 2574 2575 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2573 def deletion_protection @deletion_protection end |
#encryption_config ⇒ Google::Apis::MetastoreV1alpha::EncryptionConfig
Encryption settings for the service.
Corresponds to the JSON property encryptionConfig
2579 2580 2581 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2579 def encryption_config @encryption_config end |
#endpoint_uri ⇒ String
Output only. The URI of the endpoint used to access the metastore service.
Corresponds to the JSON property endpointUri
2584 2585 2586 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2584 def endpoint_uri @endpoint_uri end |
#hive_metastore_config ⇒ Google::Apis::MetastoreV1alpha::HiveMetastoreConfig
Specifies configuration information specific to running Hive metastore
software as the metastore service.
Corresponds to the JSON property hiveMetastoreConfig
2590 2591 2592 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2590 def @hive_metastore_config end |
#labels ⇒ Hash<String,String>
User-defined labels for the metastore service.
Corresponds to the JSON property labels
2595 2596 2597 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2595 def labels @labels end |
#maintenance_window ⇒ Google::Apis::MetastoreV1alpha::MaintenanceWindow
Maintenance window. This specifies when Dataproc Metastore may perform system
maintenance operation to the service.
Corresponds to the JSON property maintenanceWindow
2601 2602 2603 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2601 def maintenance_window @maintenance_window end |
#metadata_integration ⇒ Google::Apis::MetastoreV1alpha::MetadataIntegration
Specifies how metastore metadata should be integrated with external services.
Corresponds to the JSON property metadataIntegration
2606 2607 2608 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2606 def @metadata_integration end |
#metadata_management_activity ⇒ Google::Apis::MetastoreV1alpha::MetadataManagementActivity
The metadata management activities of the metastore service.
Corresponds to the JSON property metadataManagementActivity
2611 2612 2613 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2611 def @metadata_management_activity end |
#multi_region_config ⇒ Google::Apis::MetastoreV1alpha::MultiRegionConfig
The multi-region config for the Dataproc Metastore service.
Corresponds to the JSON property multiRegionConfig
2616 2617 2618 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2616 def multi_region_config @multi_region_config end |
#name ⇒ String
Immutable. Identifier. The relative resource name of the metastore service, in
the following format:projects/project_number/locations/location_id/
services/service_id.
Corresponds to the JSON property name
2623 2624 2625 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2623 def name @name end |
#network ⇒ String
Immutable. The relative resource name of the VPC network on which the instance
can be accessed. It is specified in the following form:projects/
project_number/global/networks/network_id.
Corresponds to the JSON property network
2630 2631 2632 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2630 def network @network end |
#network_config ⇒ Google::Apis::MetastoreV1alpha::NetworkConfig
Network configuration for the Dataproc Metastore service.
Corresponds to the JSON property networkConfig
2635 2636 2637 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2635 def network_config @network_config end |
#port ⇒ Fixnum
Optional. The TCP port at which the metastore service is reached. Default:
9083.
Corresponds to the JSON property port
2641 2642 2643 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2641 def port @port end |
#release_channel ⇒ String
Immutable. The release channel of the service. If unspecified, defaults to
STABLE.
Corresponds to the JSON property releaseChannel
2647 2648 2649 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2647 def release_channel @release_channel end |
#scaling_config ⇒ Google::Apis::MetastoreV1alpha::ScalingConfig
Represents the scaling configuration of a metastore service.
Corresponds to the JSON property scalingConfig
2652 2653 2654 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2652 def scaling_config @scaling_config end |
#scheduled_backup ⇒ Google::Apis::MetastoreV1alpha::ScheduledBackup
This specifies the configuration of scheduled backup.
Corresponds to the JSON property scheduledBackup
2657 2658 2659 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2657 def scheduled_backup @scheduled_backup end |
#state ⇒ String
Output only. The current state of the metastore service.
Corresponds to the JSON property state
2662 2663 2664 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2662 def state @state end |
#state_message ⇒ String
Output only. Additional information about the current state of the metastore
service, if available.
Corresponds to the JSON property stateMessage
2668 2669 2670 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2668 def @state_message end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this
resource. For example: "123/environment": "production", "123/costCenter": "
marketing"
Corresponds to the JSON property tags
2675 2676 2677 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2675 def @tags end |
#telemetry_config ⇒ Google::Apis::MetastoreV1alpha::TelemetryConfig
Telemetry Configuration for the Dataproc Metastore service.
Corresponds to the JSON property telemetryConfig
2680 2681 2682 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2680 def telemetry_config @telemetry_config end |
#tier ⇒ String
Optional. The tier of the service.
Corresponds to the JSON property tier
2685 2686 2687 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2685 def tier @tier end |
#uid ⇒ String
Output only. The globally unique resource identifier of the metastore service.
Corresponds to the JSON property uid
2690 2691 2692 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2690 def uid @uid end |
#update_time ⇒ String
Output only. The time when the metastore service was last updated.
Corresponds to the JSON property updateTime
2695 2696 2697 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2695 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 2702 def update!(**args) @artifact_gcs_uri = args[:artifact_gcs_uri] if args.key?(:artifact_gcs_uri) @create_time = args[:create_time] if args.key?(:create_time) @database_type = args[:database_type] if args.key?(:database_type) @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri) @hive_metastore_config = args[:hive_metastore_config] if args.key?(:hive_metastore_config) @labels = args[:labels] if args.key?(:labels) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @metadata_integration = args[:metadata_integration] if args.key?(:metadata_integration) @metadata_management_activity = args[:metadata_management_activity] if args.key?(:metadata_management_activity) @multi_region_config = args[:multi_region_config] if args.key?(:multi_region_config) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_config = args[:network_config] if args.key?(:network_config) @port = args[:port] if args.key?(:port) @release_channel = args[:release_channel] if args.key?(:release_channel) @scaling_config = args[:scaling_config] if args.key?(:scaling_config) @scheduled_backup = args[:scheduled_backup] if args.key?(:scheduled_backup) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @tags = args[:tags] if args.key?(:tags) @telemetry_config = args[:telemetry_config] if args.key?(:telemetry_config) @tier = args[:tier] if args.key?(:tier) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |