Class: Google::Apis::MetastoreV1alpha::TableReport
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::TableReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Aggregated report at the table level.
Instance Attribute Summary collapse
-
#execution_plan ⇒ Google::Apis::MetastoreV1alpha::ExecutionPlan
Represents the migration plan for a specific resource (e.g. Database, Table).
-
#execution_result ⇒ Google::Apis::MetastoreV1alpha::ExecutionResult
Represents the actual migration result for a specific resource (e.g. Database, Table).
-
#partition_discovered_count ⇒ Fixnum
The total number of partitions identified at the source during discovery.
-
#partition_report ⇒ Google::Apis::MetastoreV1alpha::PartitionReport
Partition migration report for a Hive table.
-
#table ⇒ String
The name of the table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TableReport
constructor
A new instance of TableReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TableReport
Returns a new instance of TableReport.
3418 3419 3420 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3418 def initialize(**args) update!(**args) end |
Instance Attribute Details
#execution_plan ⇒ Google::Apis::MetastoreV1alpha::ExecutionPlan
Represents the migration plan for a specific resource (e.g. Database, Table).
Corresponds to the JSON property executionPlan
3394 3395 3396 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3394 def execution_plan @execution_plan end |
#execution_result ⇒ Google::Apis::MetastoreV1alpha::ExecutionResult
Represents the actual migration result for a specific resource (e.g. Database,
Table).
Corresponds to the JSON property executionResult
3400 3401 3402 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3400 def execution_result @execution_result end |
#partition_discovered_count ⇒ Fixnum
The total number of partitions identified at the source during discovery. This
is only relevant for Hive Partitioned tables.
Corresponds to the JSON property partitionDiscoveredCount
3406 3407 3408 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3406 def partition_discovered_count @partition_discovered_count end |
#partition_report ⇒ Google::Apis::MetastoreV1alpha::PartitionReport
Partition migration report for a Hive table.
Corresponds to the JSON property partitionReport
3411 3412 3413 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3411 def partition_report @partition_report end |
#table ⇒ String
The name of the table.
Corresponds to the JSON property table
3416 3417 3418 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3416 def table @table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3423 3424 3425 3426 3427 3428 3429 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3423 def update!(**args) @execution_plan = args[:execution_plan] if args.key?(:execution_plan) @execution_result = args[:execution_result] if args.key?(:execution_result) @partition_discovered_count = args[:partition_discovered_count] if args.key?(:partition_discovered_count) @partition_report = args[:partition_report] if args.key?(:partition_report) @table = args[:table] if args.key?(:table) end |