Class: Google::Apis::MetastoreV1alpha::TableSummary
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1alpha::TableSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1alpha/classes.rb,
lib/google/apis/metastore_v1alpha/representations.rb,
lib/google/apis/metastore_v1alpha/representations.rb
Overview
Aggregated summary of results for all tables in a database.
Instance Attribute Summary collapse
-
#partition_discovered_count ⇒ Fixnum
Output only.
-
#partition_failed_count ⇒ Fixnum
Output only.
-
#partition_success_count ⇒ Fixnum
Output only.
-
#plan_counts ⇒ Hash<String,Fixnum>
Output only.
-
#result_counts ⇒ Hash<String,Fixnum>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TableSummary
constructor
A new instance of TableSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TableSummary
Returns a new instance of TableSummary.
3232 3233 3234 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3232 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partition_discovered_count ⇒ Fixnum
Output only. Partition migration summary across all Hive tables in the
database.The total number of partitions discovered at the source.
Corresponds to the JSON property partitionDiscoveredCount
3205 3206 3207 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3205 def partition_discovered_count @partition_discovered_count end |
#partition_failed_count ⇒ Fixnum
Output only. The total number of partitions that failed to migrate at the
target.
Corresponds to the JSON property partitionFailedCount
3211 3212 3213 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3211 def partition_failed_count @partition_failed_count end |
#partition_success_count ⇒ Fixnum
Output only. The total number of partitions successfully migrated at the
target.
Corresponds to the JSON property partitionSuccessCount
3217 3218 3219 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3217 def partition_success_count @partition_success_count end |
#plan_counts ⇒ Hash<String,Fixnum>
Output only. Number of tables with a specific migration plan action. The key
is the action name (e.g. CREATE, UPDATE, SKIP, etc.).
Corresponds to the JSON property planCounts
3223 3224 3225 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3223 def plan_counts @plan_counts end |
#result_counts ⇒ Hash<String,Fixnum>
Output only. Number of tables with a specific migration result status. The key
is the status name (e.g. SUCCEEDED, FAILED, SKIPPED, etc.). This is only set
if the migration is not a dry run.
Corresponds to the JSON property resultCounts
3230 3231 3232 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3230 def result_counts @result_counts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3237 3238 3239 3240 3241 3242 3243 |
# File 'lib/google/apis/metastore_v1alpha/classes.rb', line 3237 def update!(**args) @partition_discovered_count = args[:partition_discovered_count] if args.key?(:partition_discovered_count) @partition_failed_count = args[:partition_failed_count] if args.key?(:partition_failed_count) @partition_success_count = args[:partition_success_count] if args.key?(:partition_success_count) @plan_counts = args[:plan_counts] if args.key?(:plan_counts) @result_counts = args[:result_counts] if args.key?(:result_counts) end |